@@ -25,7 +25,7 @@ import shutil
 import gzip
 import inspect
 
-from datetime import datetime, timedelta
+from datetime import datetime , timedelta
 
 import datetime as _dt
 
@@ -64,6 +64,17 @@ class JsonEncoder( json.JSONEncoder ) :
 def json_encode( data ) :
     return json.dumps( data , cls = JsonEncoder )
 
+def json_save( fn , data ) :
+
+    #with open( fn , 'w', encoding='utf-8') as f:
+    #    json.dump(data, f, ensure_ascii=False, indent=4)
+
+    with open( fn , "w" ) as file:
+        file.write( json_encode( data) )
+
+
+
+
 #####################################################################
 
 # FIXME TODO aaarrggghhh!!!
